//------------------------------------------------------------------------------
//  Author:    	MXF Team
//  Comment:	MXF_TK: This class defines the evtr file interface.
//				e-VTR is a SONY VTR allowing recording and writing
//				of MXF Op1a files with MPEG-IMX / AES audio material. Use this
//				class to build MXF file having the same properties 
//				than those produced by the e-VTR.
//
//  The following convention is used for defining parameters and retrun values:
//      in : input parameter (will be used for computation in the function)
//      out : output parameter (will be modified by the function call)
//      in-out : input parameter that may be modified by the function call.
//      free : MXFTk user is reponsible for the deletion of this parameter
//             unless it is passed as a parameter of another function without 
//             the "free" tag.
//
// Copyright (c) 2008 OPENCUBE. All rights reserved.
// -----------------------------------------------------------------------------
#ifndef OC_I_EVTR_FILE_HPP
#define OC_I_EVTR_FILE_HPP

#include <mxf_tk/mxf_tk.hpp>
#include <mxf_tk/I_op1a_file.hpp>

namespace opencube
{
  namespace MXFTK_NAMESPACE
  {
    /* I_evtr_file:
     * An interface to create an evtr file. evtr files are files having the
     * same structure than those created by SONY e-VTR (MXF Op1a - MPEG IMX - AES audio)
     */
    class I_evtr_file : public I_op1a_file
    {
    private:
      virtual bool CALLING_CONVENTION set_external_material(I_concrete_material*, const wchar_t*)=0;
    };

    /*
     * Retrieves an evtr_file interface.
     * I_evtr_file** pointer to the newly allocated object
     * const char* path to the evtr file to be written.
     * Call to flush() will effectively cause the creation of
     * the file.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION NewEvtrFileInterface(I_evtr_file** /* out free */, 
                                                                       const char* /* in free */);

    /*
     * Retrieves an evtr_file interface in streaming mode.
     * I_evtr_file** pointer to the newly allocated object
     * const char* path to the evtr file to be written.
     * Call to flush() will effectively cause the creation of
     * the file.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION NewEvtrStreamInterface(I_evtr_file** /* out free */, 
                                                                         I_output_mxf_stream_task* /* in free */);

    /*
     * Frees an evtr_file interface.
     * I_evtr_file** pointer to the object to be freed.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION FreeEvtrFileInterface(I_evtr_file** /* in out */);
  }
}

#endif
