//------------------------------------------------------------------------------
//  Author:    	MXF Team
//  Comment:	MXF_TK: This class defines the umid interface.
//
//  The following convention is used for defining parameters and retrun values:
//      in : input parameter (will be used for computation in the function)
//      out : output parameter (will be modified by the function call)
//      in-out : input parameter that may be modified by the function call.
//      free : MXFTk user is reponsible for the deletion of this parameter
//             unless it is passed as a parameter of another function without 
//             the "free" tag.
//
// Copyright (c) 2008 OPENCUBE. All rights reserved.
// -----------------------------------------------------------------------------
#ifndef OC_I_UMID_HPP
#define OC_I_UMID_HPP

#include <mxf_tk/mxf_tk.hpp>

namespace opencube
{
  namespace MXFTK_NAMESPACE
  {
    /* I_umid:
     * This class represents a 32-byte umid value uniquely identifying
     * each material. 
     */
    class I_umid
    {
    public:
      /*
       * Returns the umid value as a string. It is a set of 32 bytes in an hexadecimal
       * format separated by a dot.
       * Returns NULL if an error occured.
       */
      virtual const char* CALLING_CONVENTION get_str() const=0;

      /*
       * Returns a 32-byte long buffer containing the umid value.
       * Returned pointer should not be deleted.
       * Returns NULL if an error occured.
       */
      virtual const uint8_t* CALLING_CONVENTION get_ptr() const=0;
    };

	
    /* I_umid64:
     * This class represents a 64-byte umid value uniquely identifying
     * each material. 
     */
    class I_umid64
    {
    public:
      /*
       * Returns the umid value as a string. It is a set of 64 bytes in an hexadecimal
       * format separated by a dot.
       * Returns NULL if an error occured.
       */
      virtual const char* CALLING_CONVENTION get_str() const=0;

      /*
       * Returns a 64-byte long buffer containing the umid value.
       * Returned pointer should not be deleted.
       * Returns NULL if an error occured.
       */
      virtual const uint8_t* CALLING_CONVENTION get_ptr() const=0;
    };

    /*
     * Retrieves a umid interface.
     * I_umid** pointer to the umid interface to be created.
     * uint8_t* 64-byte long buffer containing the umid value.
     * MxfTk user remains responsible for the deletion of this buffer.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION NewUmidInterfaceByArray(I_umid** /* out free */, 
                                                                          const uint8_t* /* in free */);

    /*
     * Retrieves a umid interface.
     * I_umid** pointer to the umid interface to be created.
     * const char* set of 64 bytes in an hexadecimal format separated by a dot.
     * MxfTk user remains responsible for the deletion of this buffer.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION NewUmidInterfaceByString(I_umid** /* out free */, 
                                                                           const char* /* in free */);

    /*
     * Frees a umid interface.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION FreeUmidInterface(I_umid** /* in out */);

    /*
     * Retrieves a umid interface.
     * I_umid** pointer to the umid interface to be created.
     * uint8_t* 64-byte long buffer containing the umid value.
     * MXF_TK user remains responsible for the deletion of this buffer.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION NewUmid64InterfaceByArray(I_umid64** /* out free */, 
                                                                            const uint8_t* /* in free */);

    /*
     * Retrieves a umid interface.
     * I_umid** pointer to the umid interface to be created.
     * const char* set of 64 bytes in an hexadecimal format separated by a dot.
     * MXF_TK user remains responsible for the deletion of this buffer.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION NewUmid64InterfaceByString(I_umid64** /* out free */, 
                                                                             const char* /* in free */);

    /*
     * Frees a umid interface.
     */
    extern "C" mxf_tk_API bool CALLING_CONVENTION FreeUmid64Interface(I_umid64** /* in out */);
  }
}

#endif
