//------------------------------------------------------------------------------
//  Author:    	Thierry FRANZETTI
//  Comment:	MXF_TK: This example illustrates op1a mxf file creation.
//
// Copyright (c) 2008 OPENCUBE. All rights reserved.
// -----------------------------------------------------------------------------
#if defined(BC6)	// Borland C Builder 6.0
#include <vcl.h>
#endif

#include <mxf_tk/mxf_tk.hpp>
#include <mxf_tk/I_concrete_material.hpp>
#include <mxf_tk/I_op1b_file.hpp>

#include <iostream>

using namespace opencube::MXFTK_NAMESPACE;
using namespace std;

// MxfTk error handler
I_mxf_error_handler* err_h = NULL;

//Throws an exception when an error occured 
void throw_on_error(); 

//Called if an error occured.
void display_errors();

int main(int argc, char* argv[])
{
  if (argc < 4 )
  {
    cout << "usage : out.mxf source file source file [...source file]" << endl;
    exit(0);
  }

  // the op1a mxf file we are going to write.
  I_op1b_file* pi_op1b_ext_file = NULL;

  try
  {
    wcout << L"Retrieve MxfTk Error Handler" << endl;
    if (!GetMxfErrorHandlerInterface(&err_h))
      throw 1;

    wcout << L"MxfTk Initialization" << endl;
    InitMXF_TK();
    throw_on_error();

    // EXT REF
    wcout << L"Create the op1a ext mxf file interface" << endl;
    NewOp1bFileInterface(&pi_op1b_ext_file, argv[1]);
    throw_on_error();

    // Use this to tell MxfTk to generate index tables for this file
    wcout << L"Activate Index Tables" << endl;
    pi_op1b_ext_file->set_parameter(INDEX_TABLE, "True");

    for (int i=2; i<argc; i++)
    {
      I_concrete_material* pi_conc_mat(NULL);
      wcout << L"Create external source material" << endl;
      NewExtConcreteMaterialInterface(&pi_conc_mat, argv[i]);
      throw_on_error();
  
      wcout << L"Attach material to the mxf file" << endl;
      pi_op1b_ext_file->add_material(pi_conc_mat);
      throw_on_error();    
    }

    wcout << L"Write mxf file on disk" << endl;
    pi_op1b_ext_file->flush();
    throw_on_error();

    wcout << L"Wait termination" << endl;
    pi_op1b_ext_file->wait_end_flush_thread();
    throw_on_error();
  }
  catch (int)
  {
    wcout << "An error occured!" << std::endl;
    // Retrieving details of the error(s) and display it(them).
    display_errors();
  }

  wcout << L"Close Process" << endl;
  if (pi_op1b_ext_file)
    FreeOp1bFileInterface(&pi_op1b_ext_file);

  return 0;
}

void throw_on_error()
{
  if (err_h->has_an_error())
    throw 1;
}

void display_errors()
{
  // Retrieve error handler
  if (!err_h)
    return;

  // Retrieve list of errors
  error_list* err_l = err_h->get_errors();
  if (err_l)
  {
    err_l->begin();
    I_mxf_error** ppi_mxf_error = NULL;
    while ((ppi_mxf_error = err_l->next()) != NULL) //go through the list
    {
      I_mxf_error* pi_error = *ppi_mxf_error;
      // and display each error 
      wcout << L"Error " << (int)pi_error->get_id() << L": " << pi_error->get_error_msg() << endl;
    }
    // free error list interface
    err_h->free_errors(err_l);
  }
}
